write_amset_settings¶ atomate2.amset.files.write_amset_settings(settings_updates, from_prev=False)[source]¶ Write AMSET settings to file. This function will also apply any settings specified in Atomate2Settings.AMSET_SETTINGS_UPDATE. Parameters: settings_updates (dict) – A dictionary of settings to write. from_prev (bool) – Whether apply the settings on top of an existing settings.yaml file in the current directory. Return type: None