run_elastic_deformations

atomate2.common.jobs.elastic.run_elastic_deformations(structure, deformations, prev_dir=None, prev_dir_argname=None, elastic_relax_maker=None, socket=False)[source]

Run elastic deformations.

Note, this job will replace itself with N relaxation calculations, or a single batched calculation using the socket interface to run all deformations simultaneously. This results in lower overhead as well as parallel relaxation of the deformations for TorchSim.

Parameters:
  • structure (Structure) – A pymatgen structure.

  • deformations (list of Deformation) – The deformations to apply.

  • prev_dir (str or Path or None) – A previous directory to use for copying outputs.

  • prev_dir_argname (str or None) – Argument name for the prev_dir variable.

  • elastic_relax_maker (.BaseVaspMaker, .ForceFieldRelaxMaker, or) – .TorchSimOptimizeMaker A VaspMaker, ForceFieldMaker, or TorchSimMaker to use to generate the elastic relaxation jobs.

  • socket (bool) – If True, uses the socket-io interface to run all deformations in a single job, reducing overhead. In the specific case of TorchSim, this enables batching of all structure relaxations. Note: socket=True is not supported for BaseVaspMaker.

Return type:

Response