run_phonon_displacements

atomate2.common.jobs.phonons.run_phonon_displacements(displacements, structure, supercell_matrix, phonon_maker=None, prev_dir=None, prev_dir_argname=None, socket=False)[source]

Run phonon displacements.

Note, this job will replace itself with N displacement calculations, or a single batched calculation using the socket interface to run all displacements simultaneously. This results in lower overhead as well as parallel evaluation of the displacements for TorchSim.

Parameters:
  • displacements (Sequence) – All displacements to calculate.

  • structure (Structure object) – Fully optimized structure used for phonon computations.

  • supercell_matrix (Matrix3D) – Supercell matrix for metadata.

  • phonon_maker (.BaseVaspMaker, .AseRelaxMaker, .TorchSimStaticMaker,) – .ForceFieldRelaxMaker, or .BaseAimsMaker A maker to use to generate displacement calculations. NB: this should be a static maker.

  • prev_dir (str or Path) – The previous working directory.

  • prev_dir_argname (str) – Argument name for the prev_dir variable.

  • socket (bool) – If True, uses the socket-io interface to run all displacements in a single job, reducing overhead. In the specific case of TorchSim, this enables batching of all static structure evaluations. Note: socket=True is not supported for BaseVaspMaker.

Return type:

Flow