calc_thermo_data

atomate2.common.jobs.qha.calc_thermo_data(phonon_docs, t_min=0.0, t_max=500.0, t_step=10)[source]

Save temperature-depdenent thermodynamic state variables.

Parameters:
  • phonon_docs (list of PhononBSDOSDoc) – List of phonon output documents.

  • t_min (float = 0.0) – Minimum temperature in K to compute data, defaults to 0 K.

  • t_max (float = 500.) – Maximum temperature in K to compute data, defaults to 500 K.

  • t_step (int = 10) – Increments for temperature data in K, defaults to 10 K.

Return type:

list of PhononSummaryData containing high-level thermodynamic data