AnharmonicityDoc

class atomate2.common.schemas.anharmonicity.AnharmonicityDoc(*, nsites=None, elements=None, nelements=None, composition=None, composition_reduced=None, formula_pretty=None, formula_anonymous=None, chemsys=None, volume=None, density=None, density_atomic=None, symmetry=None, phonon_doc=None, supercell_matrix='Matrix describing the supercell', structure=None, primitive_matrix='matrix describing relationship to primitive cell', sigma_dict=None, parameters_dict=None)[source]

Bases: StructureMetadata

Collection to store data from anharmonicity workflow.

Parameters:
  • nsites (int | None)

  • elements (list[Annotated[ElementTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, return_type=str, when_used=always)]] | None)

  • nelements (int | None)

  • composition (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)

  • composition_reduced (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)

  • formula_pretty (str | None)

  • formula_anonymous (str | None)

  • chemsys (str | None)

  • volume (float | None)

  • density (float | None)

  • density_atomic (float | None)

  • symmetry (SymmetryData | None)

  • phonon_doc (PhononBSDOSDoc | None)

  • supercell_matrix (tuple[tuple[float, float, float], tuple[float, float, float], tuple[float, float, float]])

  • structure (Structure | None)

  • primitive_matrix (tuple[tuple[float, float, float], tuple[float, float, float], tuple[float, float, float]])

  • sigma_dict (dict[str, Any] | None)

  • parameters_dict (dict | None)

classmethod from_phonon_doc_sigma(sigma_dict, phonon_doc, one_shot, temp, n_samples, seed)[source]

Generate the collection of data for the anharmonicity workflow.

Parameters:
  • sigma_dict (dict[str, Any]) – Dictionary of computed sigma^A values. Possible contents are full, one-shot, atom-resolved, and mode-resolved.

  • phonon_doc (PhononBSDOSDoc) – Document with data from phonon workflow

  • one_shot (bool) – True if one shot approximation was found, false otherwise

  • temp (float) – Temperature (in K) to displace structures at

  • n_samples (int) – How many displaced structures to sample

  • seed (Optional[int]) – What random seed to use for displacing structures

Returns:

Document with details about anharmonicity and phonon workflow runs

Return type:

AnharmonicityDoc

model_config = {}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].