atomate2.common.schemas.cte

Schemas for the thermal expansion workflow outputs.

Functions

get_cte

Get the thermal expansion tensor from mode Grueneisen tensors.

Classes

Boltzmann

Convert a string or number to a floating point number, if possible.

CTEDocument

Thermal expansion from mode Grueneisen tensors and the elastic tensor.

CTEResult

Thermal expansion from one set of second- and third-order force constants.

Planck

Convert a string or number to a floating point number, if possible.

TYPE_CHECKING

bool(x) -> bool