CCDDocument

class atomate2.common.schemas.defects.CCDDocument(*, q1=None, q2=None, structure1=None, structure2=None, distortions1=None, distortions2=None, energies1=None, energies2=None, static_dirs1=None, static_dirs2=None, static_uuids1=None, static_uuids2=None, relaxed_index1=None, relaxed_index2=None)[source]

Bases: BaseModel

Configuration-coordinate definition of configuration-coordinate diagram.

Parameters:
  • q1 (int | None)

  • q2 (int | None)

  • structure1 (Structure | None)

  • structure2 (Structure | None)

  • distortions1 (list[float] | None)

  • distortions2 (list[float] | None)

  • energies1 (list[float] | None)

  • energies2 (list[float] | None)

  • static_dirs1 (list[str] | None)

  • static_dirs2 (list[str] | None)

  • static_uuids1 (list[str] | None)

  • static_uuids2 (list[str] | None)

  • relaxed_index1 (int | None)

  • relaxed_index2 (int | None)

classmethod from_task_outputs(structures1, structures2, energies1, energies2, static_dirs1, static_dirs2, static_uuids1, static_uuids2, relaxed_uuid1, relaxed_uuid2)[source]

Create a CCDDocument from a lists of structures and energies.

The directories and the UUIDs of the static calculations are also provided as separate lists and zipped together.

Parameters:
  • structure1 – The structure of defect (supercell) in charge state (q1).

  • structure2 – The structure of defect (supercell) in charge state (q2).

  • energies1 (list[float]) – The energies of the defect (supercell) in charge state (q1).

  • energies2 (list[float]) – The energies of the defect (supercell) in charge state (q2).

  • static_dirs1 (list[str]) – Directories of distorted calculations for the defect (supercell) in charge state (q1).

  • static_dirs2 (list[str]) – Directories of distorted calculations for the defect (supercell) in charge state (q2).

  • static_uuids1 (list[str]) – UUIDs of distorted calculations for the defect (supercell) in charge state (q1).

  • static_uuids2 (list[str]) – UUIDs of distorted calculations for the defect (supercell) in charge state (q2).

  • relaxed_uuid1 (str) – UUID of relaxed calculation in charge state (q1).

  • relaxed_uuid2 (str) – UUID of relaxed calculation in charge state (q2).

  • structures1 (list[Structure])

  • structures2 (list[Structure])

Return type:

Self

classmethod from_entries(entries1, entries2, relaxed_uuid1=None, relaxed_uuid2=None)[source]

Create a CCDTaskDocument from a list of distorted calculations.

Parameters:
  • entries1 (list[ComputedStructureEntry]) – List of distorted calculations for charge state (q1).

  • entries2 (list[ComputedStructureEntry]) – List of distorted calculations for charge state (q2)

  • relaxed_uuid1 (str | None) – UUID of relaxed calculation in charge state (q1).

  • relaxed_uuid1 – UUID of relaxed calculation in charge state (q2).

  • relaxed_uuid2 (str | None)

Return type:

Self

get_taskdocs()[source]

Get the distorted task documents.

Return type:

tuple[list[TaskDoc], list[TaskDoc]]

model_config = {}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].