GruneisenParameterDocument

class atomate2.common.schemas.gruneisen.GruneisenParameterDocument(*, nsites=None, elements=None, nelements=None, composition=None, composition_reduced=None, formula_pretty=None, formula_anonymous=None, chemsys=None, volume=None, density=None, density_atomic=None, symmetry=None, code='String describing the code for the computation', gruneisen_parameter_inputs=None, phonon_runs_has_imaginary_modes=None, gruneisen_parameter=None, gruneisen_band_structure=None, derived_properties=None)[source]

Bases: StructureMetadata

Collection to data from the Grueneisen computation.

Parameters:
  • nsites (int | None)

  • elements (list[Annotated[ElementTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, return_type=str, when_used=always)]] | None)

  • nelements (int | None)

  • composition (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)

  • composition_reduced (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)

  • formula_pretty (str | None)

  • formula_anonymous (str | None)

  • chemsys (str | None)

  • volume (float | None)

  • density (float | None)

  • density_atomic (float | None)

  • symmetry (SymmetryData | None)

  • code (str)

  • gruneisen_parameter_inputs (GruneisenInputDirs)

  • phonon_runs_has_imaginary_modes (PhononRunsImaginaryModes | None)

  • gruneisen_parameter (GruneisenParameter | None)

  • gruneisen_band_structure (GruneisenPhononBandStructureSymmLine | None)

  • derived_properties (GruneisenDerivedProperties | None)

classmethod from_phonon_yamls(phonopy_yaml_paths_dict, structure, kpath_scheme, mesh, phonon_imaginary_modes_info, symprec, code, compute_gruneisen_param_kwargs)[source]

Generate the GruneisenParameterDocument from phonopy yamls.

Parameters:
  • phonopy_yaml_paths_dict (dict) – phonopy yaml files path for ground, expanded and contracted structure phonon runs

  • structure (.Structure) – pymatgen structure object at ground state

  • kpath_scheme (str) – scheme to generate kpoints. Please be aware that you can only use seekpath with any kind of cell Otherwise, please use the standard primitive structure Available schemes are: “seekpath”, “hinuma”, “setyawan_curtarolo”, “latimer_munro”. “seekpath” and “hinuma” are the same definition but seekpath can be used with any kind of unit cell as it relies on phonopy to handle the relationship to the primitive cell and not pymatgen

  • mesh (float or int or tuple(int, int, int)) – kpoint density (float, int) or sampling mesh (tuple(int, int, int))

  • phonon_imaginary_modes_info (dict) – dict with bool indicating if structure has imaginary modes

  • symprec (float) – Symmetry precision for symmetry checks and phonon runs.

  • code (str) – Code to compute forces

  • compute_gruneisen_param_kwargs (dict) – kwargs for phonopy Grueneisen api and pymatgen plotters

Return type:

.GruneisenParameterDocument

model_config = {}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].