PhononRunsImaginaryModes

class atomate2.common.schemas.gruneisen.PhononRunsImaginaryModes(*, ground=None, plus=None, minus=None)[source]

Bases: BaseModel

Collection with information whether structure has imaginary modes.

Information extracted from phonon run for ground, expanded and contracted structures

Parameters:
  • ground (bool | None)

  • plus (bool | None)

  • minus (bool | None)

model_config = {}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].