MagneticOrderingOutput

class atomate2.common.schemas.magnetism.MagneticOrderingOutput(*, uuid=None, dir_name=None, input=None, structure=None, ordering=None, magmoms=None, symmetry=None, energy=None, energy_per_atom=None, total_magnetization=None, total_magnetization_per_formula_unit=None, total_magnetization_per_unit_volume=None, ordering_changed=None, symmetry_changed=None, energy_above_ground_state_per_atom=None, relax_output=None, energy_diff_relax_static=None)[source]

Bases: BaseModel

Defines the output for a static magnetic ordering calculation.

This is used within the construction of the MagneticOrderingDocument. If a relaxation was performed, this information will be stored within the relax_output field.

Parameters:
  • uuid (str | None)

  • dir_name (str | None)

  • input (MagneticOrderingInput | None)

  • structure (Structure | None)

  • ordering (Ordering | None)

  • magmoms (list[float] | None)

  • symmetry (str | None)

  • energy (float | None)

  • energy_per_atom (float | None)

  • total_magnetization (float | None)

  • total_magnetization_per_formula_unit (float | None)

  • total_magnetization_per_unit_volume (float | None)

  • ordering_changed (bool | None)

  • symmetry_changed (bool | None)

  • energy_above_ground_state_per_atom (float | None)

  • relax_output (MagneticOrderingRelaxation | None)

  • energy_diff_relax_static (float | None)

classmethod from_structures_and_energies(input_structure, output_structure, output_energy, relax_output=None, uuid=None, dir_name=None, ground_state_energy_per_atom=None)[source]

Construct a MagneticOrderingOutput doc from structures and energies.

Parameters:
  • input_structure (Structure)

  • output_structure (Structure)

  • output_energy (float)

  • relax_output (MagneticOrderingRelaxation | None)

  • uuid (str | None)

  • dir_name (str | None)

  • ground_state_energy_per_atom (float | None)

Return type:

MagneticOrderingOutput

classmethod from_task_document(task_document, uuid=None, relax_output=None)[source]

Construct a MagneticOrderingOutput from a task document.

This does not include the uuid, which must be set separately.

Warning

Currently, the TaskDoc defined in emmet is VASP-specific. Ensure that the TaskDoc provided contains an InputDoc with a magnetic moments field.

Parameters:
Return type:

MagneticOrderingOutput

model_config = {}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].