PhononBSDOSDoc

class atomate2.common.schemas.phonons.PhononBSDOSDoc(*, nsites=None, elements=None, nelements=None, composition=None, composition_reduced=None, formula_pretty=None, formula_anonymous=None, chemsys=None, volume=None, density=None, density_atomic=None, symmetry=None, structure=None, phonon_bandstructure=None, phonon_dos=None, free_energies=None, heat_capacities=None, internal_energies=None, entropies=None, temperatures=None, total_dft_energy=None, volume_per_formula_unit=None, formula_units=None, has_imaginary_modes=None, force_constants=None, born=None, epsilon_static=None, supercell_matrix=None, primitive_matrix=None, code=None, phonopy_settings=None, thermal_displacement_data=None, jobdirs=None, uuids=None, **extra_data)[source]

Bases: StructureMetadata

Collection of all data produced by the phonon workflow.

Parameters:
classmethod from_forces_born(structure, supercell_matrix, displacement, sym_reduce, symprec, use_symmetrized_structure, kpath_scheme, code, displacement_data, total_dft_energy, epsilon_static=None, born=None, **kwargs)[source]

Generate collection of phonon data.

Parameters:
  • structure (Structure object)

  • supercell_matrix (numpy array describing the supercell)

  • displacement (float) – size of displacement in angstrom

  • sym_reduce (bool) – if True, phonopy will use symmetry

  • symprec (float) – precision to determine kpaths, primitive cells and symmetry in phonopy and pymatgen

  • use_symmetrized_structure (str) – primitive, conventional or None

  • kpath_scheme (str) – kpath scheme to generate phonon band structure

  • code (str) – which code was used for computation

  • displacement_data (dict[str, list]) – output of the displacement data

  • total_dft_energy (float) – total energy in eV per cell

  • epsilon_static (Matrix3D) – The high-frequency dielectric constant

  • born (Matrix3D) – Born charges

  • **kwargs – additional arguments

Return type:

Self

static get_kpath(structure, kpath_scheme, symprec, **kpath_kwargs)[source]

Get high-symmetry points in k-space in phonopy format.

Parameters:
  • structure (Structure Object)

  • kpath_scheme (str) – string describing kpath

  • symprec (float) – precision for symmetry determination

  • **kpath_kwargs – additional parameters that can be passed to this method as a dict

Return type:

tuple

model_config = {'extra': 'allow'}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].