PhononComputationalSettings

class atomate2.common.schemas.phonons.PhononComputationalSettings(*, npoints_band='number of points for band structure computation', kpath_scheme='indicates the kpath scheme', kpoint_density_dos='number of points for computation of free energies and densities of states')[source]

Bases: BaseModel

Collection to store computational settings for the phonon computation.

Parameters:
  • npoints_band (int)

  • kpath_scheme (str)

  • kpoint_density_dos (int)

model_config = {}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].