SQSTask

class atomate2.common.schemas.transform.SQSTask(*, transformation, final_structure, input_structure, sqs_method=None, final_objective=None, sqs_structures=None, sqs_scores=None, found_perfect_match=False)[source]

Bases: TransformTask

Structure the output of SQS runs.

Parameters:
  • transformation (AbstractTransformation)

  • final_structure (Structure)

  • input_structure (Structure)

  • sqs_method (SQSMethod | None)

  • final_objective (float | None)

  • sqs_structures (list[Structure] | None)

  • sqs_scores (list[float | None] | None)

  • found_perfect_match (bool)

property all_structures: list[Structure]

Return all structures, not just the most optimal SQS structure.

model_config = {}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].