AtomicKind

class atomate2.cp2k.schemas.task.AtomicKind(*, element=None, basis=None, potential=None, auxiliary_basis=None, ghost=None)[source]

Bases: BaseModel

A representation of the most important information about each type of species.

Parameters:
  • element (str)

  • basis (str)

  • potential (str)

  • auxiliary_basis (str | None)

  • ghost (bool)

model_config = {}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].