FastQuenchMLFFMDMaker

class atomate2.forcefields.flows.mpmorph.FastQuenchMLFFMDMaker(relax_maker=<factory>, static_maker=<factory>, name='ForceField fast quench', relax_maker2=<factory>)[source]

Bases: FastQuenchMaker

Fast quench from high temperature to 0K structures with forcefields.

Quenches a provided structure with a single (or double) relaxation and a static calculation at 0K.

Parameters:
classmethod from_force_field_name(force_field_name, calculator_kwargs=None)[source]

Create a fast quench maker from the force field name.

Parameters:
  • force_field_name (str or .MLFF or dict) – The name of the forcefield or its enum value

  • calculator_kwargs (dict | None) – The keyword arguments to pass to the calculator

Returns:

A fast quench maker that consists of a double relax + static using the specified MLFF.

Return type:

FastQuenchMaker