ForceFieldDielectricMaker

class atomate2.forcefields.jobs.ForceFieldDielectricMaker(force_field_name=MLFF.MACE_FIELD, calculator_meta=None, calculator_kwargs=<factory>, task_document_kwargs=<factory>, name='Force field dielectric')[source]

Bases: ForceFieldMixin, Maker

Maker for the Born effective charges and the dielectric tensor from a force field.

The force field must give the Born effective charges and the electronic susceptibility chi as the results “becs” and “polarizability”, as MACE-Field does. The high-frequency dielectric tensor is 1 + chi. Both are computed at zero electric field by default.

MACE-Field needs the MACE-Field fork of mace-torch and a model file, see the force field docs. This maker is new and less tested than the other force field makers. It might still change in future versions.

Parameters:
  • name (str) – The job name.

  • force_field_name (str or .MLFF or dict) – The name of the force field.

  • calculator_kwargs (dict) – Keyword arguments that will get passed to the ASE calculator. For MACE-Field, “model” must be set to the path of the model file.

  • calculator_meta (str | MLFF | dict | None)

  • task_document_kwargs (dict[str, Any])

make(structure, prev_dir=None)[source]

Compute the Born effective charges and the dielectric tensor.

Parameters:
  • structure (.Structure) – A pymatgen structure.

  • prev_dir (str or Path or None) – A previous calculation directory. Unused, just added to match the method signature of other makers.

Return type:

ForceFieldDielectricDocument