ForceFieldMoleculeTaskDocument¶
- class atomate2.forcefields.schemas.ForceFieldMoleculeTaskDocument(*, forcefield_name=None, forcefield_version='Unknown', dir_name=None, included_objects=None, objects=None, is_force_converged=None, charge=None, spin_multiplicity=None, natoms=None, elements=None, nelements=None, nelectrons=None, composition=None, composition_reduced=None, formula_alphabetical=None, formula_pretty=None, formula_anonymous=None, chemsys=None, symmetry=None, species_hash=None, coord_hash=None, molecule=None, input=None, output=None, ase_calculator_name=None, state=None, energy_downhill=None, tags=None)[source]¶
Bases:
AseMoleculeTaskDoc,ForceFieldMetaDocument containing information on molecule manipulation using a force field.
- Parameters:
forcefield_name (str | None)
forcefield_version (str | None)
dir_name (str | None)
included_objects (list[AseObject] | None)
is_force_converged (bool | None)
charge (int | None)
spin_multiplicity (int | None)
natoms (int | None)
elements (list[Annotated[ElementTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, return_type=str, when_used=always)]] | None)
nelements (int | None)
nelectrons (int | None)
composition (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)
composition_reduced (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)
formula_alphabetical (str | None)
formula_pretty (str | None)
formula_anonymous (str | None)
chemsys (str | None)
symmetry (PointGroupData | None)
species_hash (str | None)
coord_hash (str | None)
molecule (Molecule)
input (InputDoc)
output (OutputDoc)
ase_calculator_name (str)
state (TaskState | None)
energy_downhill (bool | None)
- classmethod from_ase_task_doc(ase_task_doc, **task_document_kwargs)[source]¶
Create a ForceFieldMoleculeTaskDocument from an AseTaskDoc.
- Parameters:
ase_task_doc (AseTaskDoc) – Task doc for the calculation
task_document_kwargs (dict) – Additional keyword args passed to
AseStructureTaskDoc().
- Return type:
Self
- model_config = {}¶
Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].