CondensedBondingAnalysis

class atomate2.lobster.schemas.CondensedBondingAnalysis(*, formula, max_considered_bond_length, limit_icohp, number_of_considered_ions, sites, type_charges, cutoff_icohp, summed_spins, start=None, cohp_plot_data, which_bonds, final_dict_bonds, final_dict_ions, run_time)[source]

Bases: BaseModel

Definition of condensed bonding analysis data from LobsterPy ICOHP.

Parameters:
classmethod from_directory(dir_name, save_cohp_plots=True, lobsterpy_kwargs=None, plot_kwargs=None, which_bonds='all')[source]

Create a task document from a directory containing LOBSTER files.

Parameters:
  • dir_name (path or str) – The path to the folder containing the calculation outputs.

  • save_cohp_plots (bool.) – Bool to indicate whether automatic cohp plots and jsons from lobsterpy will be generated.

  • lobsterpy_kwargs (dict.) – kwargs to change default lobsterpy automatic analysis parameters.

  • plot_kwargs (dict.) – kwargs to change plotting options in lobsterpy.

  • which_bonds (str.) – mode for condensed bonding analysis: “cation-anion” and “all”.

Return type:

tuple

model_config = {}

Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].