AmsetTaskDocument¶
- class atomate2.amset.schemas.AmsetTaskDocument(*, nsites=None, elements=None, nelements=None, composition=None, composition_reduced=None, formula_pretty=None, formula_anonymous=None, chemsys=None, volume=None, density=None, density_atomic=None, symmetry=None, dir_name=None, last_updated=<factory>, completed_at=None, input=None, transport=None, usage_stats=None, mesh=None, converged=None, kpoint_mesh=None, nkpoints=None, log=None, is_metal=None, scattering_labels=None, soc=None, structure=None, schema='0.0.1')[source]¶
Bases:
StructureMetadataDefinition of VASP task document.
- Parameters:
nsites (int | None)
elements (list[Annotated[ElementTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, return_type=str, when_used=always)]] | None)
nelements (int | None)
composition (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)
composition_reduced (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)
formula_pretty (str | None)
formula_anonymous (str | None)
chemsys (str | None)
volume (float | None)
density (float | None)
density_atomic (float | None)
symmetry (SymmetryData | None)
dir_name (str)
last_updated (str)
completed_at (str)
input (dict)
transport (TransportData)
usage_stats (UsageStats)
mesh (MeshData)
converged (bool)
nkpoints (int)
log (str)
is_metal (bool)
soc (bool)
structure (Structure)
schema (str)
- classmethod from_directory(dir_name, additional_fields=None, include_mesh=False)[source]¶
Create a task document from a directory containing VASP files.
- Parameters:
- Returns:
A task document for the amset calculation.
- Return type:
- model_config = {}¶
Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].