atomate2.common.schemas.cte¶
Schemas for the thermal expansion workflow outputs.
Functions
Get the thermal expansion tensor from mode Grueneisen tensors. |
Classes
Convert a string or number to a floating point number, if possible. |
|
Thermal expansion from mode Grueneisen tensors and the elastic tensor. |
|
Thermal expansion from one set of second- and third-order force constants. |
|
Convert a string or number to a floating point number, if possible. |
|
bool(x) -> bool |