MagneticOrderingRelaxation¶
- class atomate2.common.schemas.magnetism.MagneticOrderingRelaxation(*, uuid=None, dir_name=None, input=None, structure=None, symmetry_changed=None, ordering_changed=None, ordering=None, magmoms=None, symmetry=None, energy=None, energy_per_atom=None, total_magnetization=None, total_magnetization_per_formula_unit=None, total_magnetization_per_unit_volume=None)[source]¶
Bases:
BaseModelDefines the relaxation information for a magnetic ordering calculation.
This is embedded within the MagneticOrderingOutput.
- Parameters:
uuid (str | None)
dir_name (str | None)
input (MagneticOrderingInput | None)
structure (Structure | None)
symmetry_changed (bool | None)
ordering_changed (bool | None)
ordering (Ordering | None)
symmetry (str | None)
energy (float | None)
energy_per_atom (float | None)
total_magnetization (float | None)
total_magnetization_per_formula_unit (float | None)
total_magnetization_per_unit_volume (float | None)
- classmethod from_structures_and_energies(input_structure, output_structure, output_energy, uuid=None, dir_name=None)[source]¶
Construct a relaxation output doc from structures and energies.
- Parameters:
- Return type:
- classmethod from_task_document(task_document, uuid=None)[source]¶
Construct a MagneticOrderingRelaxation from a task document.
This does not include the uuid, which must be provided separately.
Warning
Currently, the TaskDoc defined in emmet is VASP-specific. Ensure that the TaskDoc provided contains an InputDoc with a magnetic moments field.
- Parameters:
task_document (TaskDoc)
uuid (str | None)
- Return type:
- model_config = {}¶
Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].