MagneticOrderingsDocument¶
- class atomate2.common.schemas.magnetism.MagneticOrderingsDocument(*, formula=None, formula_pretty=None, parent_structure=None, outputs=None, ground_state_uuid=None, ground_state_structure=None, ground_state_ordering=None, ground_state_energy=None, ground_state_energy_per_atom=None)[source]¶
Bases:
BaseModelFinal document containing information about calculated magnetic orderings.
Includes description of the ground state ordering. This document is returned by the MagneticOrderingsBuilder corresponding to your DFT code.
- Parameters:
formula (str | None)
formula_pretty (str | None)
parent_structure (Structure | None)
outputs (list[MagneticOrderingOutput] | None)
ground_state_uuid (str | None)
ground_state_structure (Structure | None)
ground_state_ordering (Ordering | None)
ground_state_energy (float | None)
ground_state_energy_per_atom (float | None)
- classmethod from_outputs(outputs, parent_structure)[source]¶
Construct a MagneticOrderingDocument from a list of output docs.
This is general and should not need to be implemented for a specific DFT code.
- Parameters:
outputs (list[MagneticOrderingOutput])
parent_structure (Structure)
- Return type:
- classmethod from_tasks(tasks)[source]¶
Construct a MagneticOrderingsDocument from a list of task dicts.
Note
this function assumes the tasks contain the keys “output” and “metadata”. These keys are automatically constructed when jobflow stores its outputs; however, you may need to put the data in this format if using this manually (as in a postprocessing job).
- Parameters:
- Return type:
- model_config = {}¶
Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].