PhononBSDOSDoc¶
- class atomate2.common.schemas.phonons.PhononBSDOSDoc(*, nsites=None, elements=None, nelements=None, composition=None, composition_reduced=None, formula_pretty=None, formula_anonymous=None, chemsys=None, volume=None, density=None, density_atomic=None, symmetry=None, structure=None, phonon_bandstructure=None, phonon_dos=None, free_energies=None, heat_capacities=None, internal_energies=None, entropies=None, temperatures=None, total_dft_energy=None, volume_per_formula_unit=None, formula_units=None, has_imaginary_modes=None, force_constants=None, born=None, epsilon_static=None, supercell_matrix=None, primitive_matrix=None, code=None, phonopy_settings=None, thermal_displacement_data=None, jobdirs=None, uuids=None, **extra_data)[source]¶
Bases:
StructureMetadataCollection of all data produced by the phonon workflow.
- Parameters:
nsites (int | None)
elements (list[Annotated[ElementTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, return_type=str, when_used=always)]] | None)
nelements (int | None)
composition (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)
composition_reduced (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)
formula_pretty (str | None)
formula_anonymous (str | None)
chemsys (str | None)
volume (float | None)
density (float | None)
density_atomic (float | None)
symmetry (SymmetryData | None)
structure (Structure | None)
phonon_bandstructure (PhononBandStructureSymmLine | None)
phonon_dos (PhononDos | None)
total_dft_energy (float | None)
volume_per_formula_unit (float | None)
formula_units (int | None)
has_imaginary_modes (bool | None)
force_constants (ForceConstants | None)
born (list[tuple[tuple[float, float, float], tuple[float, float, float], tuple[float, float, float]]] | None)
epsilon_static (tuple[tuple[float, float, float], tuple[float, float, float], tuple[float, float, float]] | None)
supercell_matrix (tuple[tuple[float, float, float], tuple[float, float, float], tuple[float, float, float]] | None)
primitive_matrix (tuple[tuple[float, float, float], tuple[float, float, float], tuple[float, float, float]] | None)
code (str | None)
phonopy_settings (PhononComputationalSettings | None)
thermal_displacement_data (ThermalDisplacementData | None)
jobdirs (PhononJobDirs | None)
uuids (PhononUUIDs | None)
extra_data (Any)
- classmethod from_forces_born(structure, supercell_matrix, displacement, sym_reduce, symprec, use_symmetrized_structure, kpath_scheme, code, displacement_data, total_dft_energy, epsilon_static=None, born=None, **kwargs)[source]¶
Generate collection of phonon data.
- Parameters:
structure (Structure object)
supercell_matrix (numpy array describing the supercell)
displacement (float) – size of displacement in angstrom
sym_reduce (bool) – if True, phonopy will use symmetry
symprec (float) – precision to determine kpaths, primitive cells and symmetry in phonopy and pymatgen
use_symmetrized_structure (str) – primitive, conventional or None
kpath_scheme (str) – kpath scheme to generate phonon band structure
code (str) – which code was used for computation
displacement_data (dict[str, list]) – output of the displacement data
total_dft_energy (float) – total energy in eV per cell
epsilon_static (Matrix3D) – The high-frequency dielectric constant
born (Matrix3D) – Born charges
**kwargs – additional arguments
- Return type:
Self
- static get_kpath(structure, kpath_scheme, symprec, **kpath_kwargs)[source]¶
Get high-symmetry points in k-space in phonopy format.
- model_config = {'extra': 'allow'}¶
Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].