ThermalDisplacementData¶
- class atomate2.common.schemas.phonons.ThermalDisplacementData(*, freq_min_thermal_displacements='cutoff frequency in THz to avoid numerical issues in the computation of the thermal displacement parameters', thermal_displacement_matrix_cif=None, thermal_displacement_matrix=None, temperatures_thermal_displacements=None)[source]¶
Bases:
BaseModelCollection to store information on the thermal displacement matrices.
- Parameters:
freq_min_thermal_displacements (float)
thermal_displacement_matrix_cif (list[list[tuple[tuple[float, float, float], tuple[float, float, float], tuple[float, float, float]]]] | None)
thermal_displacement_matrix (list[list[tuple[tuple[float, float, float], tuple[float, float, float], tuple[float, float, float]]]] | None)
- model_config = {}¶
Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].