SQSTask¶
- class atomate2.common.schemas.transform.SQSTask(*, transformation, final_structure, input_structure, sqs_method=None, final_objective=None, sqs_structures=None, sqs_scores=None, found_perfect_match=False)[source]¶
Bases:
TransformTaskStructure the output of SQS runs.
- Parameters:
- property all_structures: list[Structure]¶
Return all structures, not just the most optimal SQS structure.
- model_config = {}¶
Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].