ElectronPhononRenormalisationDoc¶
- class atomate2.vasp.schemas.elph.ElectronPhononRenormalisationDoc(*, nsites=None, elements=None, nelements=None, composition=None, composition_reduced=None, formula_pretty=None, formula_anonymous=None, chemsys=None, volume=None, density=None, density_atomic=None, symmetry=None, structure=None, temperatures=None, band_gaps=None, vbms=None, cbms=None, delta_band_gaps=None, bulk_band_gap=None, raw_data=None)[source]¶
Bases:
StructureMetadataElectron-phonon band gap renormalisation document.
- Parameters:
nsites (int | None)
elements (list[Annotated[ElementTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.element_adapter.<lambda>, return_type=str, when_used=always)]] | None)
nelements (int | None)
composition (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)
composition_reduced (Annotated[CompositionTypeVar, BeforeValidator(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, json_schema_input_type=PydanticUndefined), WrapSerializer(func=~emmet.core.types.pymatgen_types.composition_adapter.<lambda>, return_type=dict[str, float], when_used=always)] | None)
formula_pretty (str | None)
formula_anonymous (str | None)
chemsys (str | None)
volume (float | None)
density (float | None)
density_atomic (float | None)
symmetry (SymmetryData | None)
structure (Structure)
bulk_band_gap (float)
raw_data (RawElectronicData)
- classmethod from_band_structures(temperatures, displacement_band_structures, displacement_structures, displacement_uuids, displacement_dirs, bulk_band_structure, bulk_structure, bulk_uuid, bulk_dir, elph_uuid, elph_dir, original_structure)[source]¶
Calculate an electron-phonon renormalisation document from band structures.
- Parameters:
temperatures (list of float) – The temperatures at which electron phonon properties were calculated.
displacement_band_structures (list of BandStructure) – The electron-phonon displaced band structures.
displacement_structures (list of Structure) – The electron-phonon displaced structures.
displacement_uuids (list of str) – The UUIDs of the electron-phonon displaced band structure calculations.
displacement_dirs (list of str) – The calculation directories of the electron-phonon displaced band structure calculations.
bulk_band_structure (BandStructure) – The band structure of the bulk undisplaced supercell calculation.
bulk_structure (Structure) – The structure of the bulk undisplaced supercell.
bulk_uuid (str) – The UUID of the bulk undisplaced supercell band structure calculation.
bulk_dir (str) – The directory of the bulk undisplaced supercell band structure calculation.
elph_uuid (str) – The UUID of the electron-phonon calculation that generated the displaced structures.
elph_dir (str) – The directory of electron-phonon calculation that generated the displaced structures.
original_structure (Structure) – The original primitive structure for which electron-phonon calculations were performed.
- Returns:
An electron-phonon renormalisation document.
- Return type:
- model_config = {}¶
Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].